@@ -1,9 +1,9 @@
 package Lingua::EN::Opinion;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Measure the positive/negative sentiment of text
+# ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.0502';
+our $VERSION = '0.0503';
 
 use Moo;
 use strictures 2;
@@ -159,11 +159,11 @@ __END__
 
 =head1 NAME
 
-Lingua::EN::Opinion - Measure the positive/negative sentiment of text
+Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.0502
+version 0.0503
 
 =head1 SYNOPSIS
 
@@ -178,7 +178,7 @@ version 0.0502
 
 =head1 DESCRIPTION
 
-A C<Lingua::EN::Opinion> measures the positive/negative sentiment of text.
+A C<Lingua::EN::Opinion> measures the emotional sentiment of text.
 
 NOTE: This module is 3.4MB because of the GIANT sentiment text it comes with.
 
@@ -221,7 +221,7 @@ Create a new C<Lingua::EN::Opinion> object.
 
   $opinion->analyze();
 
-Measure the positive/negative sentiment of text.  This method sets the B<scores>
+Measure the emotional sentiment of text.  This method sets the B<scores>
 and B<sentences> attributes.
 
 =head2 averaged_score()
@@ -254,6 +254,8 @@ This is given by a 0/1 list of these 10 emotional elements:
   surprise
   trust
 
+This method sets the B<nrc_scores> attribute.
+
 =head1 SEE ALSO
 
 L<Moo>
@@ -268,6 +270,8 @@ L<https://www.cs.uic.edu/~liub/FBS/sentiment-analysis.html#lexicon>
 
 L<http://saifmohammad.com/WebPages/NRC-Emotion-Lexicon.htm>
 
+L<http://techn.ology.net/book-of-revelation-sentiment-analysis/>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
